from django.shortcuts import render

# Create your views here.

from django.shortcuts import render, redirect
from .models import Topic, Entry
from .forms import TopicForm, EntryForm
from django.contrib.auth.decorators import login_required
from django.http import Http404

@login_required
def index(request):
    ''' 学习笔记的主页 '''
    return render(request, 'learning_logs/index.html')

@login_required
def topics(request):
    ''' 显示题目 '''


    topics = Topic.objects.filter(owner=request.user).order_by('date_added')

    # topics = Topic.objects.order_by('date_added')
    context = {'topics':topics}

    return render(request, 'learning_logs/topics.html', context)

@login_required
def topic(request, topic_id):
    ''' 显示内容 '''
    topic = Topic.objects.get(id = topic_id)

    # 确认请求的主题属于当前用户
    if topic.owner != request.user:
        raise Http404

    entries = topic.entry_set.order_by('-date_added')
    context = {'topic':topic, 'entries':entries}
    return render(request, 'learning_logs/topic.html', context)

@login_required
def new_topic(request):
    ''' 添加标题 '''
    if request.method != 'POST':
        # POST提交的数据: 对数据进行处理。
        form = TopicForm
    else:
        # POST提交数据
        form = TopicForm(data=request.POST)
        if form.is_valid():
            new_topic = form.save(commit=False)
            new_topic.owner = request.user
            new_topic.save()
            # form.save()
            return redirect('learning_logs:topics')

    # 显示空表单或指出表单数据无效
    context = {'form':form}
    return render(request, 'learning_logs/new_topic.html', context)

@login_required
def new_entry(request, topic_id):
    ''' 在指定的标题里添加内容 '''
    topic = Topic.objects.get(id=topic_id)

    if request.method != 'POST':
        # 未提交数据: 创建新表单
        form = EntryForm()
    else:
        # POST提交的数据: 对数据进行处理。
        form = EntryForm(data=request.POST)
        if form.is_valid():
            new_entry = form.save(commit=False)
            new_entry.topic = topic
            new_entry.save()
            return redirect('learning_logs:topic', topic_id=topic_id)

    # 显示空表单或指出表单数据无效
    context = {'topic':topic,'form':form}
    return render(request, 'learning_logs/new_entry.html', context)

@login_required
def edit_entry(request, entry_id):
    ''' 编辑内容 '''
    entry = Entry.objects.get(id=entry_id)
    topic = entry.topic

    # 确认请求的主题属于当前用户
    if topic.owner != request.user:
        raise Http404

    if request.method != 'POST':
        # 初次请求 : 请用当前条目填充表单
        form = EntryForm(instance=entry)
    else:
        # POST提交的数据: 对数据进行处理
        form = EntryForm(instance=entry, data=request.POST)
        if form.is_valid():
            form.save()
            return redirect('learning_logs:topic', topic_id=topic.id)

    context = {'entry':entry, 'topic':topic, 'form':form}
    return render(request, 'learning_logs/edit_entry.html', context)
